@@ -1,10 +1,4 @@
-from tkinter import E
-from verify import get_errors_fails, mark_incomplete, mark_complete
-import requests
-import json
-import os
-
-
+from .verify import get_errors_fails, mark_incomplete, mark_complete
 
 errors, fails = get_errors_fails('milestone_1.txt')
 errors.extend(fails)
